@@ -4,13 +4,13 @@ package Archive::Builder::Section;
 
 use 5.005;
 use strict;
-use Scalar::Util 'refaddr';
-use Params::Util '_INSTANCE';
+use Scalar::Util     ('refaddr');
+use Params::Util     ('_INSTANCE');
 use Archive::Builder ();
 
 use vars qw{$VERSION %_PARENT};
 BEGIN {
-	$VERSION = '1.15';
+	$VERSION = '1.16';
 	%_PARENT = ();
 }
 
@@ -138,6 +138,19 @@ sub _archive_content {
 	\%tree;
 }
 
+# Get the archive mode hash
+sub _archive_mode {
+	my $self = shift;
+
+	# Add for each file that needs an executable bit
+	my %tree = ();
+	foreach my $File ( $self->file_list ) {
+		$tree{$File->path} = $File->{executable} ? 0755 : 0644;
+	}
+
+	\%tree;
+}
+
 
 
 
